import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user"; // 引入开关组件
type CheckedType = boolean | string | number;


export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'modelName',
    width: 150,
    onEditRow:true
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 150,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 150,
  },
  {
    title: '拥有者',
    dataIndex: 'holder',
    width: 150,
  },
];
export const dataSetColumns: BasicColumn[] = [
  {
    title: '元数据',
    dataIndex: 'orginalData',
    width: 150,
  },
  {
    title: '物理模型',
    dataIndex: 'physicsModel',
    width: 150,
    editable: true,
    edit: true,
    editComponent:'Select',
    editComponentProps: {
      options: [
        {
          label: '表名',
          value: '1',
        },
        {
          label: '中文名',
          value: '2',
        },
        {
          label: '列名',
          value: '3',
        },
        {
          label: '列中文名',
          value: '4',
        },
        {
          label: '英文名',
          value: '5',
        },
        {
          label: '列英文名',
          value: '6',
        },
      ],
    },
  },
];
export const detailColumns: BasicColumn[] = [
  {
    title: '属性名称',
    dataIndex: 'name',
    width: 150,
  },
  {
    title: '描述',
    dataIndex: 'description',
    width: 150,
  },
  {
    title: '属性英文名',
    dataIndex: 'englishName',
    width: 150,
  },
  {
    title: '是否必填',
    dataIndex: 'isWrite',
    width: 150,
    customRender: ({ record }) => (record.isWrite === '1' ? '是' : '否'),
  },
  {
    title: '是否显示',
    dataIndex: 'isShow',
    width: 150,
    customRender: ({ record }) => (record.isShow === '1' ? '是' : '否'),
  },
  {
    title: '类型',
    dataIndex: 'type',
    width: 200,
    customRender: ({ record }) => {
      const typeMap = {
        '1': '字符串',
        '2': '布尔',
        '3': '整型',
        '4': '浮点型',
      };
      return typeMap[record.type];
    },
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入元模型名称',
    },
    colProps: { span: 7 },
  },
];
export const modelFormSchema: any[] = [
  {
    field: 'modelId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'modelName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'modelName',
    label: '元模型名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入登录名',
      },
    ],
  },
  {
    field: 'type',
    label: '数据资产类型',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options:[
        {
          label: 'ArgoDB表',
          value: 'ArgoDB',
        },
        {
          label: 'DB2表',
          value: 'DB2',
        },
        {
          label: '达梦数据库表',
          value: '达梦',
        },
        {
          label: 'Hana表',
          value: 'Hana',
        },
        {
          label: 'Inceptor表',
          value: 'Inceptor',
        },
        {
          label: 'KunDB表',
          value: 'KunDB',
        },
        {
          label: 'MySQL表',
          value: 'MySQL',
        },
      ]
    },
    rules: [
      {
        required: true,
        message: '请输入数据资产类型',
      },
    ],
  },
];

/**移动*/
export const MoveFormSchema: any[] = [
  {
    field: 'modelId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'modelName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
]

export const createFileFormSchema: any[] = [
  {
    field: 'modelId',
    label: '文件夹路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'modelName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'modelName',
    label: '文件夹名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入登录名',
      },
    ],
  },
];
