import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Tag, Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
// 引入开关组件
type CheckedType = boolean | string | number;

export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'modelName',
    width: 150,
    onEditRow: true,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 150,
  },
  {
    title: '更新时间',
    dataIndex: 'updateDate',
    width: 150,
  },
  {
    title: '拥有者',
    dataIndex: 'holder',
    width: 150,
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入元模型名称',
    },
    colProps: { span: 7 },
  },
];
export const modelFormSchema: any[] = [
  {
    field: 'modelId',
    label: '路径',
    component: 'TreeSelect',
    labelWidth: 120,
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'modelName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'modelName',
    label: '元模型名称',
    component: 'Input',
    labelWidth: 120,
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入登录名',
      },
    ],
  },
  {
    field: 'type',
    label: '标准类型',
    component: 'Select',
    labelWidth: 120,
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        {
          label: '基础标准',
          value: '基础标准',
        },
        {
          label: '指标标准',
          value: '指标标准',
        },
      ],
    },
    rules: [
      {
        required: true,
        message: '请输入标准类型',
      },
    ],
  },
  {
    field: 'nameDictionary',
    label: '命名字典强映射',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '开启', value: '1' },
        { label: '关闭', value: '0' },
      ],
    },
    required: true,
    labelWidth: 120,
    colProps: { lg: 24, md: 24 },
  },
];

/**移动*/
export const MoveFormSchema: any[] = [
  {
    field: 'modelId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'modelName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];
export const dataSetColumns: BasicColumn[] = [
  {
    title: '元数据',
    dataIndex: 'orginalData',
    width: 150,
  },
  {
    title: '物理模型',
    dataIndex: 'physicsModel',
    width: 150,
    editable: true,
    edit: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: '表名',
          value: '1',
        },
        {
          label: '中文名',
          value: '2',
        },
        {
          label: '列名',
          value: '3',
        },
        {
          label: '列中文名',
          value: '4',
        },
        {
          label: '英文名',
          value: '5',
        },
        {
          label: '列英文名',
          value: '6',
        },
      ],
    },
  },
];

export const createFileFormSchema: any[] = [
  {
    field: 'modelId',
    label: '文件夹路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'modelName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'modelName',
    label: '文件夹名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入登录名',
      },
    ],
  },
];
